@@ -1,6 +1,6 @@
 /*
 fields, Tools for spatial data
-Copyright 2004-2007, Institute for Mathematics Applied Geosciences
+Copyright 2004-2016, Institute for Mathematics Applied Geosciences
 University Corporation for Atmospheric Research
 Licensed under the GPL -- www.gpl.org/licenses/gpl.html
 */
@@ -23,7 +23,11 @@ SEXP compactToMatC(SEXP compactMat, SEXP len, SEXP n, SEXP diagVal, SEXP lowerTr
   cMat = REAL(compactMat);
   SEXP ans = PROTECT(allocMatrix(REALSXP, In, In));
   cans = REAL(ans);
-  
+  //intialize entire array to zero DWN May-1-2016
+  for(i = 0; i < (In*In); i++) {
+        cans[i]= 0.0;
+    }
+    
   //set upper or lower triangle of output matrix
   index = 0;
   if(lTri) {
